@@ -10,14 +10,14 @@ __PACKAGE__->load_namespaces(
     default_resultset_class => 'ResultSet',
 );
 
-our $VERSION = 34; # schema version used for upgrades, keep as integer
+our # try to hide from kwalitee
+  $VERSION = 42; # schema version used for upgrades, keep as integer
 
 use Path::Class;
-use File::Basename;
+use File::ShareDir 'dist_dir';
 
-my (undef, $libpath, undef) = fileparse( $INC{ 'App/Netdisco/DB.pm' } );
-our $schema_versions_dir = Path::Class::Dir->new($libpath)
-  ->subdir("DB", "schema_versions")->stringify;
+our $schema_versions_dir = Path::Class::Dir->new( dist_dir('App-Netdisco') )
+  ->subdir('schema_versions')->stringify;
 
 __PACKAGE__->load_components(qw/
   Schema::Versioned
