@@ -2,12 +2,14 @@ package App::Netdisco::Util::DNS;
 
 use strict;
 use warnings;
-
 use Dancer ':script';
+
 use Net::DNS;
 use AnyEvent::DNS;
 use NetAddr::IP::Lite ':lower';
 
+use App::Netdisco::Util::Permission 'check_acl';
+
 use base 'Exporter';
 our @EXPORT = ();
 our @EXPORT_OK = qw/
@@ -15,6 +17,18 @@ our @EXPORT_OK = qw/
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
+# AE::DNS::EtcHosts only works for A/AAAA/SRV, but we want PTR.
+# this loads+parses /etc/hosts file using AE. dirty hack.
+use AnyEvent::Socket 'format_address';
+use AnyEvent::DNS::EtcHosts;
+AnyEvent::DNS::EtcHosts::_load_hosts_unless(sub{},AE::cv);
+no AnyEvent::DNS::EtcHosts; # unimport
+
+our %HOSTS = ();
+$HOSTS{$_} = [ map { [ $_ ? (format_address $_->[0]) : '' ] }
+                    @{$AnyEvent::DNS::EtcHosts::HOSTS{$_}} ]
+  for keys %AnyEvent::DNS::EtcHosts::HOSTS;
+
 =head1 NAME
 
 App::Netdisco::Util::DNS
@@ -40,6 +54,13 @@ sub hostname_from_ip {
   my $ip = shift;
   return unless $ip;
 
+  # check /etc/hosts file and short-circuit if found
+  foreach my $name (reverse sort keys %HOSTS) {
+      if ($HOSTS{$name}->[0]->[0] eq $ip) {
+          return $name;
+      }
+  }
+
   my $res   = Net::DNS::Resolver->new;
   my $query = $res->search($ip);
 
@@ -65,6 +86,12 @@ sub ipv4_from_hostname {
   my $name = shift;
   return unless $name;
 
+  # check /etc/hosts file and short-circuit if found
+  if (exists $HOSTS{$name} and $HOSTS{$name}->[0]->[0]) {
+      my $ip = NetAddr::IP::Lite->new($HOSTS{$name}->[0]->[0]);
+      return $ip->addr if $ip and $ip->bits == 32;
+  }
+
   my $res   = Net::DNS::Resolver->new;
   my $query = $res->search($name);
 
@@ -85,47 +112,28 @@ resolver C<AnyEvent::DNS>.
 
 Given a reference to an array of hashes will resolve the C<IPv4> or C<IPv6>
 address in the C<ip> or C<alias> key of each hash into its hostname which
-will be inserted in the C<dns> key of the hash.  The resolver does also
-forward-lookups to verify that the resolved hostnames point to the
-address.
+will be inserted in the C<dns> key of the hash.
 
 Returns the supplied reference to an array of hashes with dns values for
 addresses which resolved.
 
 =cut
 
-# AE::DNS::EtcHosts only works for A/AAAA/SRV, but we want PTR.
-# this loads+parses /etc/hosts file using AE. dirty hack.
-
-BEGIN {
-  use AnyEvent::Socket 'format_address';
-
-  use AnyEvent::DNS::EtcHosts;
-  AnyEvent::DNS::EtcHosts::_load_hosts_unless(sub{},AE::cv);
-  no AnyEvent::DNS::EtcHosts; # unimport
-
-  $AnyEvent::DNS::EtcHosts::HOSTS{$_}
-    = [ map { [ format_address $_->[0] ] }
-        @{$AnyEvent::DNS::EtcHosts::HOSTS{$_}} ]
-    for keys %AnyEvent::DNS::EtcHosts::HOSTS;
-}
-
 sub hostnames_resolve_async {
-  my $ips = shift;
+  my $ips  = shift;
+  my $skip = setting('dns')->{'no'};
 
-  my $resolver = AnyEvent::DNS->new();
-    
   # Set up the condvar
   my $done = AE::cv;
   $done->begin( sub { shift->send } );
 
   IP: foreach my $hash_ref (@$ips) {
     my $ip = $hash_ref->{'ip'} || $hash_ref->{'alias'};
-    next IP if no_resolve($ip);
+    next IP if check_acl($ip, $skip);
 
     # check /etc/hosts file and short-circuit if found
-    foreach my $name (reverse sort keys %AnyEvent::DNS::EtcHosts::HOSTS) {
-        if ($AnyEvent::DNS::EtcHosts::HOSTS{$name}->[0]->[0] eq $ip) {
+    foreach my $name (reverse sort keys %HOSTS) {
+        if ($HOSTS{$name}->[0]->[0] eq $ip) {
             $hash_ref->{'dns'} = $name;
             next IP;
         }
@@ -141,34 +149,11 @@ sub hostnames_resolve_async {
 
   # Wait for the resolver to perform all resolutions
   $done->recv;
+  
+  # Remove reference to resolver so that we close sockets
+  undef $AnyEvent::DNS::RESOLVER if $AnyEvent::DNS::RESOLVER;
 
   return $ips;
 }
 
-=head2 no_resolve( $ip )
-
-Given an IP address, returns true if excluded from DNS resolution by the
-C<dns_no> configuration directive, otherwise returns false.
-
-=cut
-
-sub no_resolve {
-    my $ip = shift;
-
-    my $config = setting('dns')->{no} || [];
-    return 0 if not scalar @$config;
-
-    my $addr = NetAddr::IP::Lite->new($ip);
-
-    foreach my $item (@$config) {
-        my $c_ip = NetAddr::IP::Lite->new($item)
-            or next;
-        next unless $c_ip->bits == $addr->bits;
-
-        return 1 if ($c_ip->contains($addr));
-    }
-    return 0;
-}
-
 1;
-
